import click
import json
from oktapy.okta import Okta


@click.group()
def cli():
    """Okta User Management"""

    pass


@cli.command(short_help='Get cuurent user')
@click.pass_context
def current(ctx):
    """Get cuurent user."""

    userMgr = Okta(ctx.obj.get('base_url'), token=ctx.obj.get('api_token')).UserMgr()
    currentUser = userMgr.getCurrentUser()
    print(currentUser.profile["login"])
    print(currentUser.profile)


@cli.command(short_help='List all users')
@click.option('-f', '--file', 'output_file', type=click.File(mode="w"), help='Output JSON file')
@click.pass_context
def list(ctx, output_file):
    """List all users. Optionally save them to a file."""

    userMgr = Okta(ctx.obj.get('base_url'), token=ctx.obj.get('api_token')).UserMgr()
    users_list = userMgr.getUsers()

    if(output_file):
        json.dump([json.loads(str(ob)) for ob in users_list], output_file, indent=4, sort_keys=True)
        click.echo(f"Saved users in {output_file.name}")
    else:
        print(users_list)


@cli.command(short_help='Create a single user')
@click.option('-f', '--file', 'input_file', type=click.File(), help='Input JSON file')
@click.pass_context
def create(ctx, input_file):
    """Create a single user from input or a json file."""

    # userMgr = Okta(ctx.obj.get('base_url'), token=ctx.obj.get('api_token')).UserMgr()

    if(input_file):
        click.echo(f"Creating users from {input_file.name}")
    else:
        click.echo("Creating users from input")


@cli.command(short_help='Delete a single user')
@click.argument('userid')
@click.pass_context
def delete(ctx, userid):
    """Delete a single user.

    USERID login or internal ID.
    """
    userMgr = Okta(ctx.obj.get('base_url'), token=ctx.obj.get('api_token')).UserMgr()
    user = userMgr.getUser(userid)
    print(user.id)

    click.echo(f"Deleting user {userid}")
    result = userMgr.deleteUser(user.id)
    print(result)



import click
import os
import json


@click.group(invoke_without_command=True)
@click.pass_context
def cli(ctx):
    """Store configuration values."""

    if ctx.invoked_subcommand is None:
        config_file = os.path.expanduser('~/.okt.cfg')

        base_url = click.prompt(
            "Enter Okta Org URL",
            default=ctx.obj.get('base_url', 'https://example.okta.com')
        )

        api_token = click.prompt(
            "Enter API Token",
            default=ctx.obj.get('api_token', '')
        )

        config = {
            'api_token': api_token,
            'base_url': base_url
        }

        with open(config_file, 'w') as cfg:
            cfg.write(json.dumps(config))


@cli.command()
@click.pass_context
def list(ctx):
    """Show current profile."""

    api_token = ctx.obj['api_token']
    base_url = ctx.obj['base_url']
    print(f"base_url={base_url}")
    print(f"api_token={api_token}")



import click
import os
import json

plugin_folder = os.path.join(os.path.dirname(__file__), 'commands')

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


class OktaCLI(click.MultiCommand):

    def list_commands(self, ctx):
        rv = []
        for filename in os.listdir(plugin_folder):
            if filename.endswith('.py') and not filename.startswith('__init__'):
                rv.append(filename[:-3])
        rv.sort()
        return rv

    def get_command(self, ctx, name):
        ns = {}
        fn = os.path.join(plugin_folder, name + '.py')
        with open(fn) as f:
            code = compile(f.read(), fn, 'exec')
            eval(code, ns, ns)
        return ns['cli']


@click.command(cls=OktaCLI, context_settings=CONTEXT_SETTINGS)
@click.option(
    '--config-file', '-c',
    type=click.Path(),
    default='~/.okt.cfg',
)
@click.pass_context
def cli(ctx, config_file):
    """CLI tool for your Okta org."""
    filename = os.path.expanduser(config_file)

    if os.path.exists(filename):
        with open(filename) as cfg:
            config = json.loads(cfg.read())
        ctx.obj = {
            'base_url': config['base_url'],
            'api_token': config['api_token'],
            'config_file': filename
        }
    else:
        ctx.obj = {
            'config_file': filename
        }


if __name__ == '__main__':
    cli()



import os
import sys

from setuptools import setup, find_packages
from setuptools.command.install import install

# circleci.py version
VERSION = "0.0.3"

with open("README.md", "r") as fh:
    long_description = fh.read()

class VerifyVersionCommand(install):
    """Custom command to verify that the git tag matches our version"""
    description = 'verify that the git tag matches our version'

    def run(self):
        tag = os.getenv('CIRCLE_TAG')

        if tag != VERSION:
            info = "Git tag: {0} does not match the version of this app: {1}".format(
                tag, VERSION
            )
            sys.exit(info)

setup(
    name="okt",
    version=VERSION,
    py_modules=['okt'],
    entry_points='''
        [console_scripts]
        okt=okt:cli
    ''',
    author="Indranil Jha",
    author_email="indranilokg@gmail.com",
    description="CLI tool for Okta",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/indranilokg/okta-cli",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    license="MIT",
    keywords='okta cli api',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    cmdclass={
        'verify': VerifyVersionCommand,
    },
    install_requires=[
        'click>=7.0',
        'oktapysdk'
    ],
)
